Skip to contents

Draws the marker of geom_focus() with the label of its legend entry inside. The label is looked up from the info value of the key in params$info_labels; without a match only the marker is drawn.

Usage

draw_key_focus(data, params, size)

Arguments

data

A single row data frame with the scaled aesthetics.

params

A list of layer parameters.

size

Width and height of the key in mm (unused).

Value

A grob.